package xtc.samples.sax;

import xtc.driver.*;
import xtc.server.XTCexception;

import org.xml.sax.*;

class Sax1
{
    static XTCconnection connection = null;

    static class MyContentHandler extends org.xml.sax.helpers.DefaultHandler
    {
        public void startElement(String namespaceURI, String lName, String qName, Attributes attrs) throws SAXException
        {
            System.out.print ("<" + qName);

            if (attrs != null)
            {
                for (int i = 0; i < attrs.getLength(); i++)
                {
                    System.out.print (" " + attrs.getQName(i) + "=\"" + attrs.getValue(i) + "\"");
                }
            }
            System.out.println (">");
        } // startElement

        public void endElement(String namespaceURI, String lName, String qName) throws SAXException
        {
            System.out.println ("</" + qName + ">");
        } // endElement

        public void characters(char ch[], int start, int length) throws SAXException
        {
            System.out.println (new String(ch, start, length));
        } // characters

    } // MyContentHandler

    public static void main (String[] args)
    {
        if (args.length != 4)
        {
            System.out.println ("\n\nWrong parameters: <host> <port> <username> <password> required.");
            System.exit (0);
        }

        String host           = args[0];
        int    port           = new Integer(args[1]).intValue();
        String username       = args[2];
        String password       = args[3];

        try
        {
            connection = XTCdriver.getConnection (host, port, username, password);
        }
        catch (XTCexception e)
        {
            System.out.println (e.getMessage());
            System.exit (0);
        }

        try
        {
            connection.beginWork ("Sax example 1");

            org.w3c.dom.Document document = connection.getDocument ("sample.xml");

            MyContentHandler myContentHandler = new MyContentHandler ();
            connection.saxParse (document, myContentHandler);
        }
        catch (XTCexception e)
        {
            System.out.println (e.getMessage());
            System.exit (0);
        }

        try
        {
            connection.commitWork ();
        }
        catch (XTCexception e)
        {
            System.out.println (e.getMessage());
            System.exit (0);
        }

        connection.close ();
    } // main

} // class Sax1