package xtc.samples.xquery;

import xtc.driver.*;
import xtc.server.XTCexception;

class XQuery1
{
    static XTCconnection connection = null;

    public static void main (String[] args)
    {
        if (args.length != 4)
        {
            System.out.println ("\n\nWrong parameters: <host> <port> <username> <password> required.");
            System.exit (0);
        }

        String host           = args[0];
        int    port           = new Integer(args[1]).intValue();
        String username       = args[2];
        String password       = args[3];

        try
        {
            connection = XTCdriver.getConnection (host, port, username, password);
            System.out.println ("Connected.");
        }
        catch (XTCexception e)
        {
            System.out.println (e.getMessage());
            System.exit (0);
        }

        try
        {
            connection.beginWork ("XQuery sample 1");

            org.w3c.dom.Document document = connection.getDocument ("sample.xml");
            
            XTCxqueryResult result = connection.executeXQuery (document, "doc(\".\")/bib/book/title", true, true);
            
            System.out.println ("");
            if (result.getStringResult() != null)
            {
                System.out.println (result.getStringResult());
            }
            else if (result.getDocumentResult() != null)
            {
                org.w3c.dom.Element resultRoot = result.getDocumentResult().getDocumentElement();
                printTree (resultRoot, 0);
            }
            System.out.println ("");
        }
        catch (XTCexception e)
        {
            System.out.println (e.getMessage());
            System.exit (0);
        }

        try
        {
            connection.commitWork ();
            System.out.println ("Committed.");
            connection.close ();
        }
        catch (XTCexception e)
        {
            System.out.println (e.getMessage());
            System.exit (0);
        }
    } // main

    static void printTree (org.w3c.dom.Node node, int level)
    {
        for (int i=0; i < level * 2; i++) System.out.print (" ");

        if (node.getNodeType() == org.w3c.dom.Node.ELEMENT_NODE)
        {
            System.out.print ("<" + node.getNodeName());
            printAttributes(node);
            System.out.println (">");

            org.w3c.dom.Node child = node.getFirstChild();
            while (child != null)
            {
                printTree (child, level + 1);
                child = child.getNextSibling ();
            }

            for (int i=0; i < level * 2; i++) System.out.print (" ");
            System.out.println ("</" + node.getNodeName() + ">");
        } // if element
        else System.out.println (node.getNodeValue());
    } // printTree

    static void printAttributes (org.w3c.dom.Node element)
    {
        org.w3c.dom.NamedNodeMap attributeList = element.getAttributes ();

        for (int i=0; i < attributeList.getLength(); i++)
        {
            org.w3c.dom.Attr attribute = (org.w3c.dom.Attr)attributeList.item (i);

            System.out.print (" " + attribute.getName() + "=\"" + attribute.getValue() + "\"");
        }
    } // printAttributes
    
} // class XQuery1